/*****************************************************************************

  ConconiTest

  Main Program for displaying results of a Conconi Test

  $Name: Funplot_v10 $
  $Revision: 1.2 $
  $Date: 2006/03/23 11:09:05 $

  Copyright (C) 1998-2006 Domenico Reggio, Software-Engineering.

*****************************************************************************/

#include "FileInOut.h"
#include "Funplot.h"


int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR lpszCmdLine, int nCmdShow)
{
  // Register the Funplot window class
  Funplot::ClassRegister(hInstance, hPrevInstance, nCmdShow);

  // Set Default values
  Funplot::SetDefValue("showPoints",SHOW);  // You want to see points at the data pairs
  Funplot::SetDefValue("numSubTicks",5);    // Subdivide main ticks with 5 minor ticks

  // Conconi filename and program variables
  char   filename[100], legendString[100];
  short  fileOpenRequest, graphNum;
  double lapLength, time, heartBeat;

  // Instantiation of a Funplot window
  Funplot CoFun("Conconi Test");
  CoFun.SetLables("Velocity  [ km/h ]","Heart Beat  [ 1/min ]",
                  "Conconi Test");
  CoFun.SetRange(8,20,120,200);
  CoFun.SetTicks(1,5,0.1,1);
  CoFun.ShowCoorSystem(SHOW_HALF);
  CoFun.ShowGrid(SHOW_YAXIS);       // Only want to see the y-grids
  CoFun.ShowLegend(SHOW_DOWNRIGHT); // Show the legend at down right corner
  CoFun.Rise();

  // Tell your Funplot you want to read your own data for opening and adding
  CoFun.SetUserFile(OPEN|ADD|DATA_FILE);
  // Generate the first open request
  CoFun.FileOpen(OPEN|DATA_FILE);

  while (1)
  {
    // Ask Funplot for a file open request message
    fileOpenRequest= CoFun.CheckUserFileRequest();

    // Work if there is a request
    if (fileOpenRequest!=NO_REQUEST) {

      // Ask the user for file input, and proceed if filename valid
      if (CoFun.FileOpenDialogBox(filename, "Conconi File",
                                  "Conconi Data Files", "dat"))
      {
        // In case of open request delete actual graphs and then update
        if (fileOpenRequest & OPEN) {
          CoFun.DeleteAllGraphs();
        }

        // Add a new graph
        graphNum= CoFun.NewGraph();

        // Process the conconi file
        FileIn CoFile;
        CoFile.Open(filename);            // Open the Conconi file
        CoFile.ReadSignificantLine();     // Read a line without comments
        CoFile.GetString(legendString);   // Reads "legend" string in quotes
        CoFile.ReadSignificantLine();     // Read next line without comments
        CoFile.Get(lapLength);            // Get the length of the lap

        // Assign the legend string as graph lable
        CoFun.SetGraphLable(legendString, graphNum);

        // Loop over all data pairs in file
        while (CoFile.ReadSignificantLine()!=EOF)
        {
          CoFile.Get(time);               // Get the time for the lap
          CoFile.Get(heartBeat);          // Get the heart beat rate
          // Output on Funplot window for actual graph
          CoFun.LineTo(lapLength/time*3.6, heartBeat, graphNum);
        }
        CoFile.Close();                   // Close the Conconi File
        CoFun.AutoRange();
        CoFun.SetTicks(0.5,5,0.1,1);
        CoFun.Update();
      }
    }

    // Allow user interaction ...
    Funplot::MessageCheck();

    // ... and leave in case of stop
    if (Funplot::CheckUserBreak()==QUIT) break;
  }

  return 0;
}
